@@ -30,7 +30,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifdef KWIN_BUILD_TABBOX
 #include "tabbox.h"
 #endif
+#ifdef KWIN_BUILD_SCRIPTING
 #include "scripting/scriptedeffect.h"
+#endif
 #include "thumbnailitem.h"
 #include "workspace.h"
 #include "kwinglutils.h"
@@ -1282,6 +1284,7 @@ bool EffectsHandlerImpl::loadEffect(const QString& name, bool checkDefault)
 
 bool EffectsHandlerImpl::loadScriptedEffect(const QString& name, KService *service)
 {
+#ifdef KWIN_BUILD_SCRIPTING
     const KDesktopFile df("services", service->entryPath());
     const QString scriptName = df.desktopGroup().readEntry<QString>("X-Plasma-MainScript", "");
     if (scriptName.isEmpty()) {
@@ -1301,6 +1304,11 @@ bool EffectsHandlerImpl::loadScriptedEffect(const QString& name, KService *servi
     effect_order.insert(service->property("X-KDE-Ordering").toInt(), EffectPair(name, effect));
     effectsChanged();
     return true;
+#else
+    Q_UNUSED(name)
+    Q_UNUSED(service)
+    return false;
+#endif
 }
 
 void EffectsHandlerImpl::unloadEffect(const QString& name)
