@@ -167,7 +167,8 @@ public:
     void toggleEffect(const QString& name);
     void unloadEffect(const QString& name);
     void reconfigureEffect(const QString& name);
-    bool isEffectLoaded(const QString& name);
+    bool isEffectLoaded(const QString& name) const;
+    QString supportInformation(const QString& name) const;
     QStringList loadedEffects() const;
     QStringList listOfEffects() const;
 
@@ -186,6 +187,7 @@ protected Q_SLOTS:
     void slotClientAdded(KWin::Client *c);
     void slotClientShown(KWin::Toplevel*);
     void slotUnmanagedAdded(KWin::Unmanaged *u);
+    void slotUnmanagedShown(KWin::Toplevel*);
     void slotWindowClosed(KWin::Toplevel *c);
     void slotClientActivated(KWin::Client *c);
     void slotDeletedRemoved(KWin::Deleted *d);
