@@ -45,7 +45,7 @@ bool ScreenShotEffect::supported()
 ScreenShotEffect::ScreenShotEffect()
     : m_scheduledScreenshot(0)
 {
-    connect ( effects, SIGNAL(windowClosed(EffectWindow*)), SLOT(windowClosed(EffectWindow*)) );
+    connect ( effects, SIGNAL(windowClosed(KWin::EffectWindow*)), SLOT(windowClosed(KWin::EffectWindow*)) );
     QDBusConnection::sessionBus().registerObject("/Screenshot", this, QDBusConnection::ExportScriptableContents);
     QDBusConnection::sessionBus().registerService("org.kde.kwin.Screenshot");
 }
@@ -126,6 +126,7 @@ void ScreenShotEffect::postPaintScreen()
                 GLRenderTarget::popRenderTarget();
                 ScreenShotEffect::convertFromGLImage(img, width, height);
             }
+#ifdef KWIN_HAVE_XRENDER_COMPOSITING
             if (effects->compositingType() == XRenderCompositing) {
                 setXRenderOffscreen(true);
                 effects->drawWindow(m_scheduledScreenshot, mask, QRegion(0, 0, width, height), d);
@@ -133,6 +134,7 @@ void ScreenShotEffect::postPaintScreen()
                     img = xRenderOffscreenTarget()->toImage().copy(0, 0, width, height);
                 setXRenderOffscreen(false);
             }
+#endif
 
             if (m_type & INCLUDE_CURSOR) {
                 grabPointerImage(img, m_scheduledScreenshot->x() + left, m_scheduledScreenshot->y() + top);
@@ -174,6 +176,16 @@ void ScreenShotEffect::screenshotWindowUnderCursor(int mask)
     }
 }
 
+void ScreenShotEffect::screenshotForWindow(qulonglong winid, int mask)
+{
+    m_type = (ScreenShotType) mask;
+    EffectWindow* w = effects->findWindow(winid);
+    if(w && !w->isMinimized() && !w->isDeleted()) {
+        m_scheduledScreenshot = w;
+        m_scheduledScreenshot->addRepaintFull();
+    }
+}
+
 QString ScreenShotEffect::screenshotFullscreen()
 {
     return blitScreenshot(QRect(0, 0, displayWidth(), displayHeight()));
@@ -215,6 +227,7 @@ QString ScreenShotEffect::blitScreenshot(const QRect &geometry)
     }
 
     if (effects->compositingType() == XRenderCompositing) {
+#ifdef KWIN_HAVE_XRENDER_COMPOSITING
         QPixmap buffer(geometry.size());
         if (buffer.handle() == 0) {
             Pixmap xpix = XCreatePixmap(display(), rootWindow(), geometry.width(), geometry.height(), 32);
@@ -223,6 +236,7 @@ QString ScreenShotEffect::blitScreenshot(const QRect &geometry)
         XRenderComposite(display(), PictOpSrc, effects->xrenderBufferPicture(), None, buffer.x11PictureHandle(),
                                     0, 0, 0, 0, geometry.x(), geometry.y(), geometry.width(), geometry.height());
         img = buffer.toImage();
+#endif
     }
 
     KTemporaryFile temp;
