@@ -270,12 +270,15 @@ bool SceneOpenGL::initBufferConfigs()
     fbcbuffer_nondb = NULL;
 
     for (int i = 0; i < 2; i++) {
-        int back, stencil, depth, caveat, alpha;
+        int back, stencil, depth, caveat, msaa_buffers, msaa_samples, alpha;
         back = i > 0 ? INT_MAX : 1;
         stencil = INT_MAX;
         depth = INT_MAX;
         caveat = INT_MAX;
+        msaa_buffers = INT_MAX;
+        msaa_samples = INT_MAX;
         alpha = 0;
+
         for (int j = 0; j < cnt; j++) {
             XVisualInfo *vi;
             int visual_depth;
@@ -322,10 +325,26 @@ bool SceneOpenGL::initBufferConfigs()
                                  GLX_CONFIG_CAVEAT, &caveat_value);
             if (caveat_value > caveat)
                 continue;
+
+            int msaa_buffers_value;
+            glXGetFBConfigAttrib(display(), fbconfigs[j], GLX_SAMPLE_BUFFERS,
+                                 &msaa_buffers_value);
+            if (msaa_buffers_value > msaa_buffers)
+                continue;
+
+            int msaa_samples_value;
+            glXGetFBConfigAttrib(display(), fbconfigs[j], GLX_SAMPLES,
+                                 &msaa_samples_value);
+            if (msaa_samples_value > msaa_samples)
+                continue;
+
             back = back_value;
             stencil = stencil_value;
             depth = depth_value;
             caveat = caveat_value;
+            msaa_buffers = msaa_buffers_value;
+            msaa_samples = msaa_samples_value;
+
             if (i > 0)
                 fbcbuffer_nondb = fbconfigs[ j ];
             else
@@ -468,7 +487,6 @@ int SceneOpenGL::paint(QRegion damage, ToplevelList toplevels)
         stacking_order.append(windows[ c ]);
     }
 
-    grabXServer();
     glXWaitX();
     if (m_resetModelViewProjectionMatrix) {
         // reset model view projection matrix if required
@@ -487,7 +505,6 @@ int SceneOpenGL::paint(QRegion damage, ToplevelList toplevels)
 
     glFlush();
 
-    ungrabXServer();
     if (m_overlayWindow->window())  // show the window only after the first pass,
         m_overlayWindow->show();   // since that pass may take long
 
